@@ -11,7 +11,6 @@ __all__ = [
     'ConfBool',
     'ConfInt',
     'ConfTupleOfStrings',
-    'ConfTupleOfUnicode',
     'ConfTupleOfTupleOfStrings',
     'ConfPassword',
     'ConfDirectory',
@@ -25,11 +24,12 @@ import os
 import time
 import signal
 import types
+import sets
 
 from getmailcore.exceptions import *
-from getmailcore.compatibility import *
 import getmailcore.logging
-from getmailcore.utilities import eval_bool, expand_user_vars
+from getmailcore.utilities import eval_bool, expand_user_vars, lock_file, \
+    unlock_file
 
 #
 # Base classes
@@ -45,6 +45,14 @@ class ConfItem:
         self.default = default
         self.required = required
 
+    def __getitem__(self, key):
+        # Backward-compatibility hack to enable ConfigurableBase.checkconf()
+        # to access the name attribute like the old-style dictionaries.
+        # :TODO: cc - remove when all configuration items converted to classes
+        if key == 'name':
+            return self.name
+        raise KeyError(key)
+
     def validate(self, configuration, val=None):
         if val is None:
             # If not passed in by subclass
@@ -61,11 +69,11 @@ class ConfItem:
             # Got value, but not of expected type.  Try to convert.
             if self.securevalue:
                 self.log.debug('converting %s to type %s\n'
-                               % (self.name, self.dtype))
+                    % (self.name, self.dtype))
             else:
                 self.log.debug('converting %s (%s) to type %s\n'
-                               % (self.name, val, self.dtype))
-
+                    % (self.name, val, self.dtype))
+            
             try:
                 if self.dtype == bool:
                     val = eval_bool(val)
@@ -79,30 +87,30 @@ class ConfItem:
         return val
 
 class ConfInstance(ConfItem):
-    def __init__(self, name, default=None, required=True):
-        ConfItem.__init__(self, name, types.InstanceType, default=default,
+    def __init__(self, name, default=None, required=None):
+        ConfItem.__init__(self, name, types.InstanceType, default=default, 
                           required=required)
 
 class ConfString(ConfItem):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfItem.__init__(self, name, str, default=default, required=required)
 
 class ConfBool(ConfItem):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfItem.__init__(self, name, bool, default=default, required=required)
 
 class ConfInt(ConfItem):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfItem.__init__(self, name, int, default=default, required=required)
 
 class ConfTupleOfStrings(ConfString):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfString.__init__(self, name, default=default, required=required)
-
+    
     def validate(self, configuration):
         val = ConfItem.validate(self, configuration)
         try:
-            if not val:
+            if val is None or val is '':
                 val = '()'
             tup = eval(val)
             if type(tup) != tuple:
@@ -115,48 +123,14 @@ class ConfTupleOfStrings(ConfString):
         result = [str(item) for item in val]
         return tuple(result)
 
-class ConfTupleOfUnicode(ConfString):
-    def __init__(self, name, default=None, required=True, allow_specials=()):
-        ConfString.__init__(self, name, default=default, required=required)
-        self.specials = allow_specials
-
-    def validate(self, configuration):
-        _locals = dict([(v, v) for v in self.specials])
-        val = ConfItem.validate(self, configuration)
-        try:
-            if not val:
-                val = '()'
-            tup = eval(val, {}, _locals)
-            if tup in self.specials:
-                val = [tup]
-            else:
-                if type(tup) != tuple:
-                    raise ValueError('not a tuple')
-                vals = []
-                for item in tup:
-                    item = str(item)
-                    try:
-                        vals.append(item.decode('ascii'))
-                    except UnicodeError, o:
-                        try:
-                            vals.append(item.decode('utf-8'))
-                        except UnicodeError, o:
-                            raise ValueError('not ascii or utf-8: %s' % item)
-                val = vals
-        except (ValueError, SyntaxError), o:
-            raise getmailConfigurationError(
-                '%s: incorrect format (%s)' % (self.name, o)
-            )
-        return tuple(val)
-
 class ConfTupleOfTupleOfStrings(ConfString):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfString.__init__(self, name, default=default, required=required)
-
+    
     def validate(self, configuration):
         val = ConfItem.validate(self, configuration)
         try:
-            if not val:
+            if val is None or val is '':
                 val = '()'
             tup = eval(val)
             if type(tup) != tuple:
@@ -182,9 +156,9 @@ class ConfPassword(ConfString):
     securevalue = True
 
 class ConfDirectory(ConfString):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfString.__init__(self, name, default=default, required=required)
-
+    
     def validate(self, configuration):
         val = ConfString.validate(self, configuration)
         if val is None:
@@ -192,14 +166,15 @@ class ConfDirectory(ConfString):
         val = expand_user_vars(val)
         if not os.path.isdir(val):
             raise getmailConfigurationError(
-                '%s: specified directory "%s" does not exist' % (self.name, val)
+                '%s: specified directory "%s" does not exist'
+                % (self.name, val)
             )
         return val
 
 class ConfFile(ConfString):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfString.__init__(self, name, default=default, required=required)
-
+    
     def validate(self, configuration):
         val = ConfString.validate(self, configuration)
         if val is None:
@@ -207,7 +182,8 @@ class ConfFile(ConfString):
         val = expand_user_vars(val)
         if not os.path.isfile(val):
             raise getmailConfigurationError(
-                '%s: specified file "%s" does not exist' % (self.name, val)
+                '%s: specified file "%s" does not exist'
+                % (self.name, val)
             )
         return val
 
@@ -218,7 +194,8 @@ class ConfMaildirPath(ConfDirectory):
             return None
         if not val.endswith('/'):
             raise getmailConfigurationError(
-                '%s: maildir must end with "/"' % self.name
+                '%s: maildir must end with "/"'
+                % self.name
             )
         for subdir in ('cur', 'new', 'tmp'):
             subdirpath = os.path.join(val, subdir)
@@ -230,9 +207,9 @@ class ConfMaildirPath(ConfDirectory):
         return val
 
 class ConfMboxPath(ConfString):
-    def __init__(self, name, default=None, required=True):
+    def __init__(self, name, default=None, required=None):
         ConfString.__init__(self, name, default=default, required=required)
-
+    
     def validate(self, configuration):
         val = ConfString.validate(self, configuration)
         if val is None:
@@ -240,27 +217,22 @@ class ConfMboxPath(ConfString):
         val = expand_user_vars(val)
         if not os.path.isfile(val):
             raise getmailConfigurationError(
-                '%s: specified mbox file "%s" does not exist' % (self.name, val)
+                '%s: specified mbox file "%s" does not exist'
+                % (self.name, val)
             )
         fd = os.open(val, os.O_RDWR)
-        status_old = os.fstat(fd)
         f = os.fdopen(fd, 'r+b')
+        lock_file(f)
         # Check if it _is_ an mbox file.  mbox files must start with "From "
         # in their first line, or are 0-length files.
         f.seek(0, 0)
         first_line = f.readline()
+        unlock_file(f)
         if first_line and first_line[:5] != 'From ':
             # Not an mbox file; abort here
-            raise getmailConfigurationError('%s: not an mboxrd file' % val)
-        # Reset atime and mtime
-        try:
-            os.utime(val, (status_old.st_atime, status_old.st_mtime))
-        except OSError, o:
-            # Not root or owner; readers will not be able to reliably
-            # detect new mail.  But you shouldn't be delivering to
-            # other peoples' mboxes unless you're root, anyways.
-            pass
-
+            raise getmailConfigurationError(
+                '%s: not an mboxrd file' % val
+            )
         return val
 
 
@@ -284,17 +256,12 @@ class ConfigurableBase(object):
         self.log = getmailcore.logging.Logger()
         self.log.trace()
         self.conf = {}
-        allowed_params = set([item.name for item in self._confitems])
         for (name, value) in args.items():
-            if not name in allowed_params:
-                self.log.warning('Warning: ignoring unknown parameter "%s" '
-                                 '(value: %s)\n' % (name, value))
-                continue
             if name.lower() == 'password':
                 self.log.trace('setting %s to * (%s)\n' % (name, type(value)))
             else:
                 self.log.trace('setting %s to "%s" (%s)\n'
-                               % (name, value, type(value)))
+                    % (name, value, type(value)))
             self.conf[name] = value
         self.__confchecked = False
         self.checkconf()
@@ -304,15 +271,46 @@ class ConfigurableBase(object):
         if self.__confchecked:
             return
         for item in self._confitems:
-            # New class-based configuration item
-            self.log.trace('checking %s\n' % item.name)
-            self.conf[item.name] = item.validate(self.conf)
-        unknown_params = frozenset(self.conf.keys()).difference(
-            frozenset([item.name for item in self._confitems])
-        )
+            if type(item) == dict:
+                # Legacy configuration item
+                self.log.trace('checking %s\n' % item)
+                name = item['name']
+                dtype = item['type']
+                if not name in self.conf:
+                    # Not provided
+                    if 'default' in item:
+                        self.conf[name] = item['default']
+                    else:
+                        raise getmailConfigurationError('missing required'
+                            ' configuration parameter %s' % name)
+                elif type(self.conf[name]) is not dtype:
+                    # Value supplied, but not of expected type.  Try to convert.
+                    try:
+                        val = self.conf[name]
+                        if name.lower() == 'password':
+                            self.log.debug('converting password to type %s\n'
+                                % dtype)
+                        else:
+                            self.log.debug('converting %s (%s) to type %s\n'
+                                % (name, val, dtype))
+                        if dtype == bool:
+                            self.conf[name] = eval_bool(val)
+                        else:
+                            self.conf[name] = dtype(eval(val))
+                    except (ValueError, SyntaxError, TypeError), o:
+                        raise getmailConfigurationError('configuration value'
+                            ' %s (%s) not of required type %s (%s)'
+                            % (name, val, dtype, o))
+            else:
+                # New class-based configuration item
+                self.log.trace('checking %s\n' % item.name)
+                self.conf[item.name] = item.validate(self.conf)
+
+        unknown_params = sets.ImmutableSet(self.conf.keys()).difference(
+            sets.ImmutableSet([item['name'] for item in self._confitems]))
         for param in sorted(list(unknown_params), key=str.lower):
             self.log.warning('Warning: ignoring unknown parameter "%s" '
-                             '(value: %s)\n' % (param, self.conf[param]))
+                '(value: %s)\n' % (param, self.conf[param]))
         self.__confchecked = True
         self.log.trace('done\n')
 
@@ -368,26 +366,21 @@ class ForkingBase(object):
             self.log.trace('waiting for child %d' % childpid)
             time.sleep(1.0)
             #raise getmailDeliveryError('failed waiting for commands %s %d (%s)'
-            #                           % (self.conf['command'], childpid, o))
+            #   % (self.conf['command'], childpid, o))
         if self.__child_pid != childpid:
             #self.log.error('got child pid %d, not %d' % (pid, childpid))
-            raise getmailOperationError(
-                'got child pid %d, not %d'
-                % (self.__child_pid, childpid)
-            )
+            raise getmailOperationError('got child pid %d, not %d'
+                % (self.__child_pid, childpid))
+
         if os.WIFSTOPPED(self.__child_status):
-            raise getmailOperationError(
-                'child pid %d stopped by signal %d'
-                % (self.__child_pid, os.WSTOPSIG(self.__child_status))
-            )
+            raise getmailOperationError('child pid %d stopped by signal %d'
+                % (self.__child_pid, os.WSTOPSIG(self.__child_status)))
         if os.WIFSIGNALED(self.__child_status):
-            raise getmailOperationError(
-                'child pid %d killed by signal %d'
-                % (self.__child_pid, os.WTERMSIG(self.__child_status))
-            )
+            raise getmailOperationError('child pid %d killed by signal %d'
+                % (self.__child_pid, os.WTERMSIG(self.__child_status)))
         if not os.WIFEXITED(self.__child_status):
             raise getmailOperationError('child pid %d failed to exit'
-                                        % self.__child_pid)
+                % self.__child_pid)
         exitcode = os.WEXITSTATUS(self.__child_status)
 
         return exitcode
