@@ -26,7 +26,6 @@ __all__ = [
 
 import os
 import re
-import tempfile
 import types
 import email.Utils
 
@@ -75,13 +74,11 @@ class DeliverySkeleton(ConfigurableBase):
         try:
             self.initialize()
         except KeyError, o:
-            raise getmailConfigurationError(
-                'missing required configuration parameter %s' % o
-            )
+            raise getmailConfigurationError('missing required configuration'
+                ' parameter %s' % o)
         self.received_from = None
         self.received_with = None
         self.received_by = None
-        self.retriever = None
         self.log.trace('done\n')
 
     def retriever_info(self, retriever):
@@ -89,7 +86,6 @@ class DeliverySkeleton(ConfigurableBase):
         self.received_from = retriever.received_from
         self.received_with = retriever.received_with
         self.received_by = retriever.received_by
-        self.retriever = retriever
 
     def deliver_message(self, msg, delivered_to=True, received=True):
         self.log.trace()
@@ -108,7 +104,7 @@ class Maildir(DeliverySkeleton, ForkingBase):
       '~USER/', as well as environment variables.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfMaildirPath(name='path'),
         ConfString(name='user', required=False, default=None),
         ConfString(name='filemode', required=False, default='0600'),
@@ -122,7 +118,7 @@ class Maildir(DeliverySkeleton, ForkingBase):
             self.conf['filemode'] = int(self.conf['filemode'], 8)
         except ValueError, o:
             raise getmailConfigurationError('filemode %s not valid: %s'
-                                            % (self.conf['filemode'], o))
+                % (self.conf['filemode'], o))
 
     def __str__(self):
         self.log.trace()
@@ -132,7 +128,7 @@ class Maildir(DeliverySkeleton, ForkingBase):
         self.log.info('Maildir(%s)\n' % self._confstring())
 
     def __deliver_message_maildir(self, uid, gid, msg, delivered_to, received,
-                                  stdout, stderr):
+        stdout, stderr):
         '''Delivery method run in separate child process.
         '''
         try:
@@ -147,10 +143,8 @@ class Maildir(DeliverySkeleton, ForkingBase):
                     raise getmailConfigurationError(
                         'refuse to deliver mail as GID 0'
                     )
-            f = deliver_maildir(
-                self.conf['path'], msg.flatten(delivered_to, received),
-                self.hostname, self.dcount, self.conf['filemode']
-            )
+            f = deliver_maildir(self.conf['path'], msg.flatten(delivered_to,
+                received), self.hostname, self.dcount, self.conf['filemode'])
             stdout.write(f)
             stdout.flush()
             os.fsync(stdout.fileno())
@@ -182,14 +176,14 @@ class Maildir(DeliverySkeleton, ForkingBase):
                         'refuse to deliver mail as GID 0'
                     )
         self._prepare_child()
-        stdout = tempfile.TemporaryFile()
-        stderr = tempfile.TemporaryFile()
+        stdout = os.tmpfile()
+        stderr = os.tmpfile()
         childpid = os.fork()
 
         if not childpid:
             # Child
             self.__deliver_message_maildir(uid, gid, msg, delivered_to,
-                                           received, stdout, stderr)
+                received, stdout, stderr)
         self.log.debug('spawned child %d\n' % childpid)
 
         # Parent
@@ -201,11 +195,11 @@ class Maildir(DeliverySkeleton, ForkingBase):
         err = stderr.read().strip()
 
         self.log.debug('maildir delivery process %d exited %d\n'
-                       % (childpid, exitcode))
+            % (childpid, exitcode))
 
         if exitcode or err:
             raise getmailDeliveryError('maildir delivery %d error (%d, %s)'
-                                       % (childpid, exitcode, err))
+                % (childpid, exitcode, err))
 
         self.dcount += 1
         self.log.debug('maildir file %s' % out)
@@ -226,17 +220,13 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
     http://groups.google.com/groups?selm=4ivk9s%24bok%40hustle.rahul.net
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfMboxPath(name='path'),
-        ConfString(name='locktype', required=False, default='lockf'),
         ConfString(name='user', required=False, default=None),
     )
 
     def initialize(self):
         self.log.trace()
-        if self.conf['locktype'] not in ('lockf', 'flock'):
-            raise getmailConfigurationError('unknown mbox lock type: %s'
-                                            % self.conf['locktype'])
 
     def __str__(self):
         self.log.trace()
@@ -246,7 +236,7 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
         self.log.info('Mboxrd(%s)\n' % self._confstring())
 
     def __deliver_message_mbox(self, uid, gid, msg, delivered_to, received,
-                               stdout, stderr):
+        stdout, stderr):
         '''Delivery method run in separate child process.
         '''
         try:
@@ -264,38 +254,43 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
 
             if not os.path.exists(self.conf['path']):
                 raise getmailDeliveryError('mboxrd does not exist (%s)'
-                                           % self.conf['path'])
+                    % self.conf['path'])
             if not os.path.isfile(self.conf['path']):
                 raise getmailDeliveryError('not an mboxrd file (%s)'
-                                           % self.conf['path'])
+                    % self.conf['path'])
 
             # Open mbox file, refusing to create it if it doesn't exist
             fd = os.open(self.conf['path'], os.O_RDWR)
             status_old = os.fstat(fd)
             f = os.fdopen(fd, 'r+b')
-            lock_file(f, self.conf['locktype'])
+            lock_file(f)
             # Check if it _is_ an mbox file.  mbox files must start with "From "
             # in their first line, or are 0-length files.
             f.seek(0, 0)
             first_line = f.readline()
-            if first_line and not first_line.startswith('From '):
+            if first_line and first_line[:5] != 'From ':
                 # Not an mbox file; abort here
-                unlock_file(f, self.conf['locktype'])
+                unlock_file(f)
                 raise getmailDeliveryError('not an mboxrd file (%s)'
-                                           % self.conf['path'])
+                    % self.conf['path'])
             # Seek to end
             f.seek(0, 2)
             try:
                 # Write out message plus blank line with native EOL
-                f.write(msg.flatten(delivered_to, received, include_from=True,
-                                    mangle_from=True) + os.linesep)
+                f.write(
+                    msg.flatten(
+                        delivered_to,
+                        received,
+                        include_from=True,
+                        mangle_from=True
+                    ) + os.linesep)
                 f.flush()
                 os.fsync(fd)
                 status_new = os.fstat(fd)
                 # Reset atime
                 try:
                     os.utime(self.conf['path'], (status_old.st_atime,
-                             status_new.st_mtime))
+                        status_new.st_mtime))
                 except OSError, o:
                     # Not root or owner; readers will not be able to reliably
                     # detect new mail.  But you shouldn't be delivering to
@@ -304,7 +299,7 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
                     stdout.flush()
                     os.fsync(stdout.fileno())
 
-                unlock_file(f, self.conf['locktype'])
+                unlock_file(f)
 
             except IOError, o:
                 try:
@@ -320,8 +315,7 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
                     pass
                 raise getmailDeliveryError(
                     'failure writing message to mbox file "%s" (%s)'
-                    % (self.conf['path'], o)
-                )
+                    % (self.conf['path'], o))
 
             os._exit(0)
 
@@ -354,14 +348,14 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
                     'refuse to deliver mail as GID 0'
                 )
         self._prepare_child()
-        stdout = tempfile.TemporaryFile()
-        stderr = tempfile.TemporaryFile()
+        stdout = os.tmpfile()
+        stderr = os.tmpfile()
         childpid = os.fork()
 
         if not childpid:
             # Child
             self.__deliver_message_mbox(uid, gid, msg, delivered_to, received,
-                                        stdout, stderr)
+                stdout, stderr)
         self.log.debug('spawned child %d\n' % childpid)
 
         # Parent
@@ -373,11 +367,11 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
         err = stderr.read().strip()
 
         self.log.debug('mboxrd delivery process %d exited %d\n'
-                       % (childpid, exitcode))
+            % (childpid, exitcode))
 
         if exitcode or err:
             raise getmailDeliveryError('mboxrd delivery %d error (%d, %s)'
-                                       % (childpid, exitcode, err))
+                % (childpid, exitcode, err))
 
         if out:
             self.log.debug('mbox delivery: %s' % out)
@@ -446,19 +440,19 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
     '''
 
     _confitems = (
-        ConfInstance(name='configparser', required=False),
-        ConfFile(name='qmaillocal', required=False,
+        ConfInstance(name='configparser'),
+        ConfFile(name='qmaillocal', required=False, 
                  default='/var/qmail/bin/qmail-local'),
-        ConfString(name='user', required=False,
+        ConfString(name='user', required=False, 
                    default=pwd.getpwuid(os.geteuid()).pw_name),
         ConfString(name='group', required=False, default=None),
-        ConfDirectory(name='homedir', required=False,
+        ConfDirectory(name='homedir', required=False, 
                       default=pwd.getpwuid(os.geteuid()).pw_dir),
         ConfString(name='localdomain', required=False, default=localhostname()),
-        ConfString(name='defaultdelivery', required=False,
+        ConfString(name='defaultdelivery', required=False, 
                    default='./Maildir/'),
         ConfString(name='conf-break', required=False, default='-'),
-        ConfTupleOfStrings(name='localpart_translate', required=False,
+        ConfTupleOfStrings(name='localpart_translate', required=False, 
                            default="('', '')"),
         ConfBool(name='strip_delivered_to', required=False, default=False),
         ConfBool(name='allow_root_commands', required=False, default=False),
@@ -477,21 +471,17 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
     def _deliver_qmaillocal(self, msg, msginfo, delivered_to, received, stdout,
             stderr):
         try:
-            args = (
-                self.conf['qmaillocal'], self.conf['qmaillocal'],
+            args = (self.conf['qmaillocal'], self.conf['qmaillocal'],
                 '--', self.conf['user'], self.conf['homedir'],
                 msginfo['local'], msginfo['dash'], msginfo['ext'],
                 self.conf['localdomain'], msginfo['sender'],
-                self.conf['defaultdelivery']
-            )
+                self.conf['defaultdelivery'])
             self.log.debug('about to execl() with args %s\n' % str(args))
             # Modify message
             if self.conf['strip_delivered_to']:
-                msg.remove_header('delivered-to')
-                # Also don't insert a Delivered-To: header.
-                delivered_to = None
+                del msg['delivered-to']
             # Write out message
-            msgfile = tempfile.TemporaryFile()
+            msgfile = os.tmpfile()
             msgfile.write(msg.flatten(delivered_to, received))
             msgfile.flush()
             os.fsync(msgfile.fileno())
@@ -507,9 +497,7 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
             if ((os.geteuid() == 0 or os.getegid() == 0)
                     and not self.conf['allow_root_commands']):
                 raise getmailConfigurationError(
-                    'refuse to invoke external commands as root '
-                    'or GID 0 by default'
-                )
+                    'refuse to invoke external commands as root or GID 0 by default')
 
             os.execl(*args)
         except StandardError, o:
@@ -524,47 +512,45 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
         self.log.trace()
         self._prepare_child()
         if msg.recipient == None:
-            raise getmailConfigurationError(
-                'MDA_qmaillocal destination requires a message source that '
-                'preserves the message envelope'
-            )
+            raise getmailConfigurationError('MDA_qmaillocal destination'
+                ' requires a message source that preserves the message'
+                ' envelope (%s)')
         msginfo = {
             'sender' : msg.sender,
             'local' : '@'.join(msg.recipient.lower().split('@')[:-1])
         }
 
         self.log.debug('recipient: extracted local-part "%s"\n'
-                       % msginfo['local'])
+            % msginfo['local'])
         xlate_from, xlate_to = self.conf['localpart_translate']
         if xlate_from or xlate_to:
             if msginfo['local'].startswith(xlate_from):
                 self.log.debug('recipient: translating "%s" to "%s"\n'
-                               % (xlate_from, xlate_to))
+                    % (xlate_from, xlate_to))
                 msginfo['local'] = xlate_to + msginfo['local'][len(xlate_from):]
             else:
-                self.log.debug('recipient: does not start with xlate_from '
-                               '"%s"\n' % xlate_from)
+                self.log.debug('recipient: does not start with xlate_from'
+                    ' "%s"\n' % xlate_from)
         self.log.debug('recipient: translated local-part "%s"\n'
-                       % msginfo['local'])
+            % msginfo['local'])
         if self.conf['conf-break'] in msginfo['local']:
             msginfo['dash'] = self.conf['conf-break']
             msginfo['ext'] = self.conf['conf-break'].join(
-                msginfo['local'].split(self.conf['conf-break'])[1:]
-            )
+                msginfo['local'].split(self.conf['conf-break'])[1:])
         else:
             msginfo['dash'] = ''
             msginfo['ext'] = ''
         self.log.debug('recipient: set dash to "%s", ext to "%s"\n'
-                       % (msginfo['dash'], msginfo['ext']))
+            % (msginfo['dash'], msginfo['ext']))
 
-        stdout = tempfile.TemporaryFile()
-        stderr = tempfile.TemporaryFile()
+        stdout = os.tmpfile()
+        stderr = os.tmpfile()
         childpid = os.fork()
 
         if not childpid:
             # Child
             self._deliver_qmaillocal(msg, msginfo, delivered_to, received,
-                                     stdout, stderr)
+                stdout, stderr)
         self.log.debug('spawned child %d\n' % childpid)
 
         # Parent
@@ -579,17 +565,12 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
 
         if exitcode == 111:
             raise getmailDeliveryError('qmail-local %d temporary error (%s)'
-                                       % (childpid, err))
-        elif exitcode:
+                % (childpid, err))
+        elif exitcode or err:
             raise getmailDeliveryError('qmail-local %d error (%d, %s)'
-                                       % (childpid, exitcode, err))
+                % (childpid, exitcode, err))
 
-        if out and err:
-            info = '%s:%s' % (out, err)
-        else:
-            info = out or err
-
-        return 'MDA_qmaillocal (%s)' % info
+        return 'MDA_qmaillocal (%s)' % out
 
 #######################################
 class MDA_external(DeliverySkeleton, ForkingBase):
@@ -610,9 +591,6 @@ class MDA_external(DeliverySkeleton, ForkingBase):
                     %(recipient) - recipient address
                     %(domain) - domain-part of recipient address
                     %(local) - local-part of recipient address
-                    %(mailbox) - for IMAP retrievers, the name of the 
-                        server-side mailbox/folder the message was retrieved
-                        from.  Will be empty for POP.
 
                   Warning: the text of these replacements is taken from the
                   message and is therefore under the control of a potential
@@ -636,19 +614,15 @@ class MDA_external(DeliverySkeleton, ForkingBase):
       allow_root_commands (boolean, optional) - if set, external commands are
             allowed when running as root.  The default is not to allow such
             behaviour.
-
-      ignore_stderr (boolean, optional) - if set, getmail will not consider the
-            program writing to stderr to be an error.  The default is False.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfFile(name='path'),
         ConfTupleOfStrings(name='arguments', required=False, default="()"),
         ConfString(name='user', required=False, default=None),
         ConfString(name='group', required=False, default=None),
         ConfBool(name='allow_root_commands', required=False, default=False),
         ConfBool(name='unixfrom', required=False, default=False),
-        ConfBool(name='ignore_stderr', required=False, default=False),
     )
 
     def initialize(self):
@@ -656,28 +630,26 @@ class MDA_external(DeliverySkeleton, ForkingBase):
         self.conf['command'] = os.path.basename(self.conf['path'])
         if not os.access(self.conf['path'], os.X_OK):
             raise getmailConfigurationError('%s not executable'
-                                            % self.conf['path'])
+                % self.conf['path'])
         if type(self.conf['arguments']) != tuple:
-            raise getmailConfigurationError(
-                'incorrect arguments format; see documentation (%s)'
-                % self.conf['arguments']
-            )
+            raise getmailConfigurationError('incorrect arguments format;'
+                ' see documentation (%s)' % self.conf['arguments'])
 
     def __str__(self):
         self.log.trace()
         return 'MDA_external %s (%s)' % (self.conf['command'],
-                                         self._confstring())
+            self._confstring())
 
     def showconf(self):
         self.log.info('MDA_external(%s)\n' % self._confstring())
 
     def _deliver_command(self, msg, msginfo, delivered_to, received,
-                         stdout, stderr):
+            stdout, stderr):
         try:
             # Write out message with native EOL convention
-            msgfile = tempfile.TemporaryFile()
+            msgfile = os.tmpfile()
             msgfile.write(msg.flatten(delivered_to, received,
-                                      include_from=self.conf['unixfrom']))
+                include_from=self.conf['unixfrom']))
             msgfile.flush()
             os.fsync(msgfile.fileno())
             # Rewind
@@ -692,11 +664,8 @@ class MDA_external(DeliverySkeleton, ForkingBase):
             if ((os.geteuid() == 0 or os.getegid() == 0)
                     and not self.conf['allow_root_commands']):
                 raise getmailConfigurationError(
-                    'refuse to invoke external commands as root '
-                    'or GID 0 by default'
-                )
+                    'refuse to invoke external commands as root or GID 0 by default')
             args = [self.conf['path'], self.conf['path']]
-            msginfo['mailbox'] = self.retriever.mailbox_selected or ''
             for arg in self.conf['arguments']:
                 arg = expand_user_vars(arg)
                 for (key, value) in msginfo.items():
@@ -708,7 +677,7 @@ class MDA_external(DeliverySkeleton, ForkingBase):
             # Child process; any error must cause us to exit nonzero for parent
             # to detect it
             stderr.write('exec of command %s failed (%s)'
-                         % (self.conf['command'], o))
+                % (self.conf['command'], o))
             stderr.flush()
             os.fsync(stderr.fileno())
             os._exit(127)
@@ -724,14 +693,14 @@ class MDA_external(DeliverySkeleton, ForkingBase):
             msginfo['local'] = '@'.join(msg.recipient.split('@')[:-1])
         self.log.debug('msginfo "%s"\n' % msginfo)
 
-        stdout = tempfile.TemporaryFile()
-        stderr = tempfile.TemporaryFile()
+        stdout = os.tmpfile()
+        stderr = os.tmpfile()
         childpid = os.fork()
 
         if not childpid:
             # Child
             self._deliver_command(msg, msginfo, delivered_to, received,
-                                  stdout, stderr)
+                stdout, stderr)
         self.log.debug('spawned child %d\n' % childpid)
 
         # Parent
@@ -742,23 +711,12 @@ class MDA_external(DeliverySkeleton, ForkingBase):
         out = stdout.read().strip()
         err = stderr.read().strip()
 
-        self.log.debug('command %s %d exited %d\n'
-                       % (self.conf['command'], childpid, exitcode))
+        self.log.debug('command %s %d exited %d\n' % (self.conf['command'],
+            childpid, exitcode))
 
-        if exitcode:
-            raise getmailDeliveryError(
-                'command %s %d error (%d, %s)'
-                % (self.conf['command'], childpid, exitcode, err)
-            )
-        elif err:
-            if not self.conf['ignore_stderr']:
-                raise getmailDeliveryError(
-                    'command %s %d wrote to stderr: %s'
-                    % (self.conf['command'], childpid, err)
-                )
-            #else:
-            # User said to ignore stderr, just log it.
-            self.log.info('command %s: %s' % (self, err))
+        if exitcode or err:
+            raise getmailDeliveryError('command %s %d error (%d, %s)'
+                % (self.conf['command'], childpid, exitcode, err))
 
         return 'MDA_external command %s (%s)' % (self.conf['command'], out)
 
@@ -785,39 +743,34 @@ class MultiDestinationBase(DeliverySkeleton):
         if p.startswith('[') and p.endswith(']'):
             destsectionname = p[1:-1]
             if not destsectionname in self.conf['configparser'].sections():
-                raise getmailConfigurationError(
-                    'destination specifies section name %s which does not exist'
-                    % path
-                )
+                raise getmailConfigurationError('destination specifies section'
+                    ' name %s which does not exist' % path)
             # Construct destination instance
             self.log.debug('  getting destination for %s\n' % path)
-            destination_type = self.conf['configparser'].get(destsectionname,
-                                                             'type')
+            destination_type = self.conf['configparser'].get(
+                destsectionname, 'type')
             self.log.debug('    type="%s"\n' % destination_type)
             destination_func = globals().get(destination_type, None)
             if not callable(destination_func):
-                raise getmailConfigurationError(
-                    'configuration file section %s specifies incorrect '
-                    'destination type (%s)'
-                    % (destsectionname, destination_type)
-                )
+                raise getmailConfigurationError('configuration file section'
+                    ' %s specifies incorrect destination type (%s)'
+                    % (destsectionname, destination_type))
             destination_args = {'configparser' : self.conf['configparser']}
-            for (name, value) in self.conf['configparser'].items(destsectionname):
-                if name in ('type', 'configparser'):
-                    continue
+            for (name, value) in self.conf['configparser'].items(
+                    destsectionname):
+                if name in ('type', 'configparser'): continue
                 self.log.debug('    parameter %s="%s"\n' % (name, value))
                 destination_args[name] = value
             self.log.debug('    instantiating destination %s with args %s\n'
-                           % (destination_type, destination_args))
+                % (destination_type, destination_args))
             dest = destination_func(**destination_args)
         elif (p.startswith('/') or p.startswith('.')) and p.endswith('/'):
             dest = Maildir(path=p)
         elif (p.startswith('/') or p.startswith('.')):
             dest = Mboxrd(path=p)
         else:
-            raise getmailConfigurationError(
-                'specified destination %s not of recognized type' % p
-            )
+            raise getmailConfigurationError('specified destination %s not'
+                ' of recognized type' % p)
         return dest
 
     def initialize(self):
@@ -845,7 +798,7 @@ class MultiDestination(MultiDestinationBase):
                 then interpreted as maildir/mbox/other-destination-section.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfTupleOfStrings(name='destinations'),
     )
 
@@ -858,7 +811,7 @@ class MultiDestination(MultiDestinationBase):
                 dest = self._get_destination(item)
             except getmailConfigurationError, o:
                 raise getmailConfigurationError('%s destination error %s'
-                                                % (item, o))
+                    % (item, o))
             self._destinations.append(dest)
         if not self._destinations:
             raise getmailConfigurationError('no destinations specified')
@@ -907,17 +860,16 @@ class MultiSorterBase(MultiDestinationBase):
             for item in _locals:
                 if not (type(item) == tuple and len(item) == 2
                         and type(item[0]) == str and type(item[1]) == str):
-                    raise getmailConfigurationError(
-                        'invalid syntax for locals; see documentation'
-                    )
+                    raise getmailConfigurationError('invalid syntax for locals'
+                        ' ; see documentation')
             for (pattern, path) in _locals:
                 try:
                     dest = self._get_destination(path)
                 except getmailConfigurationError, o:
-                    raise getmailConfigurationError(
-                        'pattern %s destination error %s' % (pattern, o)
-                    )
-                self.targets.append((re.compile(pattern, re.IGNORECASE), dest))
+                    raise getmailConfigurationError('pattern %s destination'
+                        ' error %s' % (pattern, o))
+                self.targets.append( (re.compile(pattern.replace('\\', '\\\\'),
+                    re.IGNORECASE), dest) )
                 self._destinations.append(dest)
         except re.error, o:
             raise getmailConfigurationError('invalid regular expression %s' % o)
@@ -974,7 +926,7 @@ class MultiSorter(MultiSorterBase):
                with them.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfString(name='default'),
         ConfTupleOfTupleOfStrings(name='locals', required=False, default="()"),
     )
@@ -990,27 +942,25 @@ class MultiSorter(MultiSorterBase):
         self.log.trace()
         matched = []
         if msg.recipient == None and self.targets:
-            raise getmailConfigurationError(
-                'MultiSorter recipient matching requires a retriever (message '
-                'source) that preserves the message envelope'
-            )
+            raise getmailConfigurationError('MultiSorter recipient matching'
+                ' requires a retriever (message source) that preserves the'
+                ' message envelope')
         for (pattern, dest) in self.targets:
             self.log.debug('checking recipient %s against pattern %s\n'
-                           % (msg.recipient, pattern.pattern))
+                % (msg.recipient, pattern.pattern))
             if pattern.search(msg.recipient):
                 self.log.debug('recipient %s matched target %s\n'
-                               % (msg.recipient, dest))
+                    % (msg.recipient, dest))
                 dest.deliver_message(msg, delivered_to, received)
                 matched.append(str(dest))
         if not matched:
             if self.targets:
                 self.log.debug('recipient %s not matched; using default %s\n'
-                               % (msg.recipient, self.default))
+                    % (msg.recipient, self.default))
             else:
                 self.log.debug('using default %s\n' % self.default)
             return 'MultiSorter (default %s)' % self.default.deliver_message(
-                msg, delivered_to, received
-            )
+                msg, delivered_to, received)
         return 'MultiSorter (%s)' % matched
 
 #######################################
@@ -1025,7 +975,7 @@ class MultiGuesser(MultiSorterBase):
 
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfString(name='default'),
         ConfTupleOfTupleOfStrings(name='locals', required=False, default="()"),
     )
@@ -1051,18 +1001,17 @@ class MultiGuesser(MultiSorterBase):
         )
         for fields in fieldnames:
             for field in fields:
-                self.log.debug(
-                    'looking for addresses in %s header fields\n' % field
-                )
+                self.log.debug('looking for addresses in %s header fields\n'
+                    % field)
                 header_addrs.extend(
-                    [addr for (name, addr) in email.Utils.getaddresses(
-                        msg.get_all(field, [])
-                     ) if addr]
+                    [addr for (name, addr) in
+                        email.Utils.getaddresses(msg.get_all(field, []))
+                    if addr]
                 )
             if header_addrs:
                 # Got some addresses, quit here
                 self.log.debug('found total of %d addresses (%s)\n'
-                               % (len(header_addrs), header_addrs))
+                    % (len(header_addrs), header_addrs))
                 break
             else:
                 self.log.debug('no addresses found, continuing\n')
@@ -1070,10 +1019,10 @@ class MultiGuesser(MultiSorterBase):
         for (pattern, dest) in self.targets:
             for addr in header_addrs:
                 self.log.debug('checking address %s against pattern %s\n'
-                               % (addr, pattern.pattern))
+                    % (addr, pattern.pattern))
                 if pattern.search(addr):
                     self.log.debug('address %s matched target %s\n'
-                                   % (addr, dest))
+                        % (addr, dest))
                     dest.deliver_message(msg, delivered_to, received)
                     matched.append(str(dest))
                     # Only deliver once to each destination; this one matched,
@@ -1083,10 +1032,9 @@ class MultiGuesser(MultiSorterBase):
         if not matched:
             if self.targets:
                 self.log.debug('no addresses matched; using default %s\n'
-                               % self.default)
+                    % self.default)
             else:
                 self.log.debug('using default %s\n' % self.default)
             return 'MultiGuesser (default %s)' % self.default.deliver_message(
-                msg, delivered_to, received
-            )
+                msg, delivered_to, received)
         return 'MultiGuesser (%s)' % matched
