@@ -13,11 +13,12 @@ import cStringIO
 import email
 import email.Errors
 import email.Utils
+import email.Parser
 from email.Generator import Generator
 
-from exceptions import *
-from utilities import mbox_from_escape, format_header, address_no_brackets
-import logging
+from getmailcore.exceptions import *
+from getmailcore.utilities import mbox_from_escape, format_header, address_no_brackets
+import getmailcore.logging
 
 message_attributes = (
     'sender',
@@ -29,7 +30,7 @@ message_attributes = (
 
 #######################################
 def corrupt_message(why, fromlines=None, fromstring=None):
-    log = logging.logger()
+    log = getmailcore.logging.Logger()
     log.error('failed to parse retrieved message; constructing container for '
         'contents\n')
     if fromlines == fromstring == None:
@@ -73,33 +74,33 @@ class Message(object):
         'recipient',
     )
     def __init__(self, fromlines=None, fromstring=None, fromfile=None):
-        #self.log = logger()
+        #self.log = Logger()
         self.recipient = None
         self.received_by = None
         self.received_from = None
         self.received_with = None
         self.__raw = None
-
+        parser = email.Parser.HeaderParser()
+        
         # Message is instantiated with fromlines for POP3, fromstring for
         # IMAP (both of which can be badly-corrupted or invalid, i.e. spam,
         # MS worms, etc).  It's instantiated with fromfile for the output
         # of filters, etc, which should be saner.
         if fromlines:
             try:
-                self.__msg = email.message_from_string(os.linesep.join(
-                    fromlines), strict=False)
+                self.__msg = parser.parsestr(os.linesep.join(fromlines))
             except email.Errors.MessageError, o:
                 self.__msg = corrupt_message(o, fromlines=fromlines)
             self.__raw = os.linesep.join(fromlines)
         elif fromstring:
             try:
-                self.__msg = email.message_from_string(fromstring, strict=False)
+                self.__msg = parser.parsestr(fromstring)
             except email.Errors.MessageError, o:
                 self.__msg = corrupt_message(o, fromstring=fromstring)
             self.__raw = fromstring
         elif fromfile:
             try:
-                self.__msg = email.message_from_file(fromfile, strict=False)
+                self.__msg = parser.parse(fromfile)
             except email.Errors.MessageError, o:
                 # Shouldn't happen
                 self.__msg = corrupt_message(o, fromstring=fromfile.read())
